﻿using Ati.Blogs.Services;
using Ati.Blogs.ViewModels;
using Orchard;
using Orchard.Blogs.Models;
using Orchard.Blogs.Services;
using Orchard.ContentManagement;
using Orchard.Data;
using Orchard.DisplayManagement;
using Orchard.Localization;
using Orchard.Mvc.AntiForgery;
using Orchard.Settings;
using Orchard.Themes;
using Orchard.UI.Admin;
using Orchard.UI.Navigation;
using PagedList;
using System.Linq;
using System.Web.Mvc;


namespace Ati.Blogs.Controllers
{    
    public class BlogPostController : Controller
    {
        private readonly ISiteService _siteService;
        private readonly IOrchardServices _orchardService;
        private readonly IBlogService _blogService;
        private readonly IBlogAuthorService _BlogAuthorService;
        private readonly dynamic _shapeFactory;

        public Localizer T { get; set; }
        public BlogPostController(
            ISiteService siteService,
            IOrchardServices orchardService,
            IBlogService blogService,
            IShapeFactory shapeFactory,
            IBlogAuthorService BlogAuthorService
            )
        {            
            _siteService = siteService;
            _orchardService = orchardService;
            _blogService = blogService;
            _BlogAuthorService = BlogAuthorService;
            _shapeFactory = shapeFactory;

            T = NullLocalizer.Instance;
        }

        [Themed]
        public ActionResult Author(string blogSlug, string contentAuthor, PagerParameters pagerParameters)
        {
            var pager = new Pager(_siteService.GetSiteSettings(), pagerParameters);

            BlogPart blog = _blogService.Get(blogSlug);
            
            IPagedList<BlogPostPart> posts = _BlogAuthorService.BlogsByAuthor(blog, contentAuthor, pager.Page, pager.PageSize);
            dynamic pagerShape = _orchardService.New.Pager(pager).TotalItemCount(posts.TotalItemCount);

            var list = _shapeFactory.List();
            list.AddRange(posts.Select(a => _orchardService.ContentManager.BuildDisplay(a, "Summary")));
            
            return View(
                new BaseViewModel()
            { 
                ContentItems = list,
                Pager = pagerShape
            });
        }       
    }
}