﻿using Ati.Blogs.Models;
using Ati.Blogs.Services;
using Orchard;
using Orchard.Blogs.Models;
using Orchard.Blogs.Services;
using Orchard.ContentManagement;
using Orchard.ContentManagement.Drivers;
using Orchard.Localization;
using Orchard.Security;
using Orchard.Settings;
using System;

namespace Ati.Blogs.Drivers
{
    public class BlogPostAuthorWidgetDriver : ContentPartDriver<BlogPostAuthorWidgetPart>
    {
        private readonly IBlogAuthorService _BlogAuthorService;
        private readonly IContentManager _contentManager;
        private readonly ISiteService _siteService;
        private readonly IOrchardServices _orchardService;
        private readonly IBlogPostService _blogPostService;

        public Localizer T { get; set; }

        public BlogPostAuthorWidgetDriver(
            IBlogAuthorService BlogAuthorService,
            IBlogPostService blogPostService,
            IContentManager contentManager,
            ISiteService siteService,
            IOrchardServices orchardService
            )
        {
            _BlogAuthorService = BlogAuthorService;
            _blogPostService = blogPostService;
            _contentManager = contentManager;
            _siteService = siteService;
            _orchardService = orchardService;
            T = NullLocalizer.Instance;
        }
        protected override DriverResult Display(BlogPostAuthorWidgetPart part, string displayType, dynamic shapeHelper)
        {
            IUser author = null;

            if (_orchardService.WorkContext.HttpContext.Request.RequestContext.RouteData.Values.ContainsKey("contentAuthor"))
                author = _BlogAuthorService.AuthorFromUrl(_orchardService.WorkContext.HttpContext.Request.RequestContext.RouteData.Values["contentAuthor"].ToString());
            else if (_orchardService.WorkContext.HttpContext.Request.RequestContext.RouteData.Values.ContainsKey("Id"))
            {
                int postId = 0;
                if (Int32.TryParse(_orchardService.WorkContext.HttpContext.Request.RequestContext.RouteData.Values["Id"].ToString(), out postId))
                {
                    BlogPostPart blogPost = _blogPostService.Get(postId);
                    if (blogPost != null)
                        author = blogPost.Creator;
                }
            }
            dynamic authorShape = _contentManager.BuildDisplay(author.ContentItem, "summary");
            return ContentShape("Parts_BlogPostAuthorWidget",
                () => shapeHelper.Parts_BlogPostAuthorWidget(
                    Author: authorShape 
                    )
                );
        }
        protected override DriverResult Editor(BlogPostAuthorWidgetPart part, dynamic shapeHelper)
        {
            return ContentShape("Parts_BlogPostAuthorWidget_Edit",
                () => shapeHelper.EditorTemplate(
                    TemplateName: "Parts/BlogPostAuthorWidget",
                    Model: part,
                    Prefix: Prefix)
                );
        }
        protected override DriverResult Editor(BlogPostAuthorWidgetPart part, Orchard.ContentManagement.IUpdateModel updater, dynamic shapeHelper)
        {
            updater.TryUpdateModel(part, Prefix, null, null);
            return Editor(part, shapeHelper);
        }
    }
}