﻿using Orchard.Blogs.Models;
using Orchard.ContentManagement;
using Orchard.Core.Common.Models;
using Orchard.Security;
using Orchard.Users.Models;
using PagedList;
using System.Collections.Generic;
using System.Linq;

namespace Ati.Blogs.Services
{
    public class BlogAuthorService : IBlogAuthorService
    {
        private readonly IContentManager _contentManager;
        private readonly IMembershipService _membershipService;

        public BlogAuthorService(
            IContentManager contentManager,
            IMembershipService membershipService
            )
        {
            _membershipService = membershipService;
            _contentManager = contentManager;
        }
        public IPagedList<BlogPostPart> BlogsByAuthor(BlogPart blog, string userName, int pageIndex, int pageSize)
        {
            IUser user = AuthorFromUrl(userName);
            
            if (user == null)
            {
                PagedList<BlogPostPart> list = new PagedList<BlogPostPart>(new List<BlogPostPart>(), pageIndex, pageSize);
                return list;
            }

            return GetBlogQuery(blog, VersionOptions.Published)
                .Where(a => a.OwnerId == user.Id)
                .List<BlogPostPart>().ToPagedList<BlogPostPart>(pageIndex, pageSize);                        
        }
        private IContentQuery<ContentItem, CommonPartRecord> GetBlogQuery(BlogPart blog, VersionOptions versionOptions)
        {            
            return
                _contentManager.Query(versionOptions, "BlogPost")
                .Join<CommonPartRecord>().Where(
                    cr => cr.Container.Id == blog.Id).OrderByDescending(cr => cr.CreatedUtc)
                    ;
        }

        public IUser AuthorFromUrl(string userName)
        {
            if (string.IsNullOrEmpty(userName))
                return null;

            return _membershipService.GetUser(userName);
        }
    }
}